# Wasd2Play

![](https://github.com/viktor02/wasd2play/raw/master/img/hello.png)

Open any stream in your favorite player!

### Requirements
`pip install -r requirements.txt`

### Help
```
usage: wasd2play [options] url

Open any stream in your favorite player!

positional arguments:
  url                   stream url

optional arguments:
  -h, --help            show this help message and exit
  -p YOUR_PLAYER, --player YOUR_PLAYER
                        point your player
  -l, --last            open last stream
```